from typing import Literal

TTSModels = Literal["lightning"]
TTSLanguages = Literal["en", "hi"]
TTSVoices = Literal["emily", "jasmine", "arman", "james", "mithali", "aravind", "raj", 
                    "arjun", "sanya", "saina", "pooja", "saurabh", "nisha", "mansi", "radhika", "kajal", 
                    "raghav", "deepika", "niharika", "monika", "raman", "diya", "ananya", "william"]